"""System Bridge Windows Sensors"""
import os


def get_windowssensors_path() -> str:
    """Get windows sensors path (absolute)"""
    return os.path.abspath(
        os.path.join(os.path.dirname(__file__), "bin/SystemBridgeWindowsSensors.exe"),
    )



"""
Provides systembridgewindowssensors version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update systembridgewindowssensors` to change this file.

from incremental import Version

__version__ = Version("systembridgewindowssensors", 3, 1, 2, dev=4)
__all__ = ["__version__"]
